@@ -95,7 +95,8 @@ class VariableOsInstallX11Resolution(ResolutionVariable):
     type = 'choiceedit'
     opt = ['-X']
     metavalue = "<width>x<height>"
-    fallback_resolution = "1024x768"
+    # разрешение пустое, так как xorg.conf использует автодетект на livecd
+    fallback_resolution = ""
 
     def init(self):
         self.help = _("set the Xorg resolution")
